#include <mex.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include "imageio.h"
#include "dmzhangwu.h"

void mexFunction(
    int nlhs,
    mxArray *plhs[],
    int nrhs,
    const mxArray *prhs[]
)
{

    if ( mxIsChar(prhs[0]) != 1)
        mexErrMsgIdAndTxt( "MATLAB:zwmex:inputNotString",
                           "Input must be a string.");

    /* input must be a row vector */
    if (mxGetM(prhs[0])!=1)
        mexErrMsgIdAndTxt( "MATLAB:zwmex:inputNotVector",
                           "Input must be a row vector.");

    /* copy the string data from prhs[0] into a C string input_ buf.    */
    char * input_buf = mxArrayToString(prhs[0]);

    if(input_buf == NULL)
        mexErrMsgIdAndTxt( "MATLAB:zwmex:conversionFailed",
                           "Could not convert input to string.");

    int Width, Height;

    float * Input = (float *)ReadImage(&Width, &Height,
                                       input_buf, IMAGEIO_FLOAT | IMAGEIO_RGB | IMAGEIO_PLANAR);

    float * Output = (float *)Malloc(sizeof(float)*3*
                                     ((long int)Width)*((long int)Height));

    /* Flatten the input to a 2D array RGGB */
    CfaFlatten(Input, Input, Width, Height, 0, 0);

    /* Perform demosaicing */
    ZhangWuDemosaic(Output, Input, Width, Height, 0, 0, 0);

    WriteImage(Output, Width, Height, "dmzw.png",
               IMAGEIO_FLOAT | IMAGEIO_RGB | IMAGEIO_PLANAR, 80);

    mxFree(input_buf);
}
